"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cdn.v1.shielding_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetShieldingDetailsRequest(google.protobuf.message.Message):
    """Request to retrieve shielding details for a specific resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which to get shielding details."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___GetShieldingDetailsRequest = GetShieldingDetailsRequest

@typing.final
class ActivateShieldingRequest(google.protobuf.message.Message):
    """Request to activate shielding for a specific resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    LOCATION_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to activate shielding for."""
    location_id: builtins.int
    """ID of the location to activate shielding in, allowing selection of a suitable geographical location."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        location_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["location_id", b"location_id", "resource_id", b"resource_id"]) -> None: ...

global___ActivateShieldingRequest = ActivateShieldingRequest

@typing.final
class ActivateShieldingMetadata(google.protobuf.message.Message):
    """Metadata for shielding activation, detailing the operations performed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which shielding is being activated."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___ActivateShieldingMetadata = ActivateShieldingMetadata

@typing.final
class DeactivateShieldingRequest(google.protobuf.message.Message):
    """Request to deactivate shielding for a specific resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource to deactivate shielding for."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeactivateShieldingRequest = DeactivateShieldingRequest

@typing.final
class DeactivateShieldingMetadata(google.protobuf.message.Message):
    """Metadata for shielding deactivation, detailing the operations performed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which shielding is being deactivated."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeactivateShieldingMetadata = DeactivateShieldingMetadata

@typing.final
class UpdateShieldingRequest(google.protobuf.message.Message):
    """Request to update shielding parameters, including location adjustments."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    LOCATION_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which shielding parameters are being updated."""
    location_id: builtins.int
    """ID of the location for updating shielding parameters, allowing for geographical adjustments."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        location_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["location_id", b"location_id", "resource_id", b"resource_id"]) -> None: ...

global___UpdateShieldingRequest = UpdateShieldingRequest

@typing.final
class UpdateShieldingMetadata(google.protobuf.message.Message):
    """Metadata for shielding updates, detailing the operations performed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the resource for which shielding parameters are being updated."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___UpdateShieldingMetadata = UpdateShieldingMetadata

@typing.final
class ListShieldingLocationsRequest(google.protobuf.message.Message):
    """Request to list available geographical locations for shielding."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder for which to request a list of locations where shielding can be activated."""
    page_size: builtins.int
    """Maximum number of results per page."""
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListShieldingLocationsResponse.next_page_token]
    returned by a previous list response.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListShieldingLocationsRequest = ListShieldingLocationsRequest

@typing.final
class ListShieldingLocationsResponse(google.protobuf.message.Message):
    """Response for the list of available shielding locations."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHIELDING_LOCATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of results."""
    @property
    def shielding_locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.shielding_pb2.ShieldingDetails]:
        """List of available shielding locations, each representing a potential geographical location for the shielding server."""

    def __init__(
        self,
        *,
        shielding_locations: collections.abc.Iterable[yandex.cloud.cdn.v1.shielding_pb2.ShieldingDetails] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "shielding_locations", b"shielding_locations"]) -> None: ...

global___ListShieldingLocationsResponse = ListShieldingLocationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AutoTranscode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AutoTranscodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AutoTranscode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AUTO_TRANSCODE_UNSPECIFIED: _AutoTranscode.ValueType  # 0
    """The auto-transcoding setting is not specified."""
    ENABLE: _AutoTranscode.ValueType  # 1
    """Automatically start transcoding after the video upload is complete."""
    DISABLE: _AutoTranscode.ValueType  # 2
    """Do not automatically transcode; requires manual initiation via the Transcode() method."""

class AutoTranscode(_AutoTranscode, metaclass=_AutoTranscodeEnumTypeWrapper):
    """Enum controlling whether videos are automatically transcoded after upload."""

AUTO_TRANSCODE_UNSPECIFIED: AutoTranscode.ValueType  # 0
"""The auto-transcoding setting is not specified."""
ENABLE: AutoTranscode.ValueType  # 1
"""Automatically start transcoding after the video upload is complete."""
DISABLE: AutoTranscode.ValueType  # 2
"""Do not automatically transcode; requires manual initiation via the Transcode() method."""
global___AutoTranscode = AutoTranscode

@typing.final
class Video(google.protobuf.message.Message):
    """Main entity representing a video in the platform."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _VideoStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VideoStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Video._VideoStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIDEO_STATUS_UNSPECIFIED: Video._VideoStatus.ValueType  # 0
        """The video status is not specified."""
        WAIT_UPLOADING: Video._VideoStatus.ValueType  # 1
        """The video upload is in progress, waiting for all bytes to be received."""
        UPLOADED: Video._VideoStatus.ValueType  # 2
        """The video has been fully uploaded and is ready for transcoding."""
        PROCESSING: Video._VideoStatus.ValueType  # 4
        """The video is currently being processed."""
        READY: Video._VideoStatus.ValueType  # 5
        """The video has been successfully processed and is ready for watching."""
        ERROR: Video._VideoStatus.ValueType  # 7
        """An error occurred during video processing."""

    class VideoStatus(_VideoStatus, metaclass=_VideoStatusEnumTypeWrapper):
        """Current processing status of the video."""

    VIDEO_STATUS_UNSPECIFIED: Video.VideoStatus.ValueType  # 0
    """The video status is not specified."""
    WAIT_UPLOADING: Video.VideoStatus.ValueType  # 1
    """The video upload is in progress, waiting for all bytes to be received."""
    UPLOADED: Video.VideoStatus.ValueType  # 2
    """The video has been fully uploaded and is ready for transcoding."""
    PROCESSING: Video.VideoStatus.ValueType  # 4
    """The video is currently being processed."""
    READY: Video.VideoStatus.ValueType  # 5
    """The video has been successfully processed and is ready for watching."""
    ERROR: Video.VideoStatus.ValueType  # 7
    """An error occurred during video processing."""

    class _VisibilityStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VisibilityStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Video._VisibilityStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VISIBILITY_STATUS_UNSPECIFIED: Video._VisibilityStatus.ValueType  # 0
        """The visibility status is not specified."""
        PUBLISHED: Video._VisibilityStatus.ValueType  # 1
        """The video is publicly available, subject to its access permission settings."""
        UNPUBLISHED: Video._VisibilityStatus.ValueType  # 2
        """The video is available only to administrators."""

    class VisibilityStatus(_VisibilityStatus, metaclass=_VisibilityStatusEnumTypeWrapper):
        """Visibility status of the video."""

    VISIBILITY_STATUS_UNSPECIFIED: Video.VisibilityStatus.ValueType  # 0
    """The visibility status is not specified."""
    PUBLISHED: Video.VisibilityStatus.ValueType  # 1
    """The video is publicly available, subject to its access permission settings."""
    UNPUBLISHED: Video.VisibilityStatus.ValueType  # 2
    """The video is available only to administrators."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    VISIBILITY_STATUS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    AUTO_TRANSCODE_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    ENABLE_AD_FIELD_NUMBER: builtins.int
    SUBTITLE_IDS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    TUSD_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the video."""
    channel_id: builtins.str
    """Identifier of the channel where the video is created and managed."""
    title: builtins.str
    """Title of the video displayed to users in interfaces and players."""
    description: builtins.str
    """Detailed description of the video content and context."""
    thumbnail_id: builtins.str
    """Identifier of the thumbnail image used to represent the video visually."""
    status: global___Video.VideoStatus.ValueType
    """Current processing status of the video."""
    error_message: builtins.str
    """Error message describing the reason for video processing failure, if any."""
    visibility_status: global___Video.VisibilityStatus.ValueType
    """Current visibility status controlling whether the video is publicly available."""
    auto_transcode: global___AutoTranscode.ValueType
    """Auto-transcoding setting that controls the video processing workflow.
    Set ENABLE to automatically initiate transcoding after upload,
    or DISABLE for manual initiation via the Transcode() method.
    """
    style_preset_id: builtins.str
    """Identifier of the style preset applied to the video during processing."""
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Total duration of the video.
        Optional, may be empty until the transcoding result is ready.
        """

    @property
    def enable_ad(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls the ability to display advertisements for this video.
        Default: true.
        Set explicitly to false to disable advertisements for a specific video.
        """

    @property
    def subtitle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of identifiers defining the active subtitles available for the video."""

    @property
    def features(self) -> global___VideoFeatures:
        """Additional video processing features and their results, such as summarization."""

    @property
    def tusd(self) -> global___VideoTUSDSource:
        """Upload video using the TUS (Tus Resumable Upload Protocol) protocol.
        @see https://tus.io/
        """

    @property
    def public_access(self) -> global___VideoPublicAccessRights:
        """Allows unrestricted public access to the video via direct link.
        No additional authorization or access control is applied.
        """

    @property
    def sign_url_access(self) -> global___VideoSignURLAccessRights:
        """Restricts video access using URL signatures for secure time-limited access."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the video was initially created in the system."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the last modification to the video or its metadata."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom user-defined labels as `key:value` pairs.
        Maximum 64 labels per video.
        Labels can be used for organization, filtering, and metadata purposes.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        status: global___Video.VideoStatus.ValueType = ...,
        error_message: builtins.str = ...,
        visibility_status: global___Video.VisibilityStatus.ValueType = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        auto_transcode: global___AutoTranscode.ValueType = ...,
        style_preset_id: builtins.str = ...,
        enable_ad: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        subtitle_ids: collections.abc.Iterable[builtins.str] | None = ...,
        features: global___VideoFeatures | None = ...,
        tusd: global___VideoTUSDSource | None = ...,
        public_access: global___VideoPublicAccessRights | None = ...,
        sign_url_access: global___VideoSignURLAccessRights | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "created_at", b"created_at", "duration", b"duration", "enable_ad", b"enable_ad", "features", b"features", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "tusd", b"tusd", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_transcode", b"auto_transcode", "channel_id", b"channel_id", "created_at", b"created_at", "description", b"description", "duration", b"duration", "enable_ad", b"enable_ad", "error_message", b"error_message", "features", b"features", "id", b"id", "labels", b"labels", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "status", b"status", "style_preset_id", b"style_preset_id", "subtitle_ids", b"subtitle_ids", "thumbnail_id", b"thumbnail_id", "title", b"title", "tusd", b"tusd", "updated_at", b"updated_at", "visibility_status", b"visibility_status"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["tusd"] | None: ...

global___Video = Video

@typing.final
class VideoTUSDSource(google.protobuf.message.Message):
    """Represents a video upload source using the TUS (Tus Resumable Upload Protocol) protocol.
    This is a push-based upload method where the client pushes data to the server.
    @see https://tus.io/
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL endpoint for uploading the video via the TUS protocol."""
    file_size: builtins.int
    """Total size of the uploaded file, in bytes."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        file_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_size", b"file_size", "url", b"url"]) -> None: ...

global___VideoTUSDSource = VideoTUSDSource

@typing.final
class VideoPublicAccessRights(google.protobuf.message.Message):
    """Represents public access rights for a video.
    When this access type is set, the video is publicly accessible via direct link.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoPublicAccessRights = VideoPublicAccessRights

@typing.final
class VideoSignURLAccessRights(google.protobuf.message.Message):
    """Represents access rights controlled by URL signatures.
    When this access type is set, the video is accessible only via properly signed temporary link.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoSignURLAccessRights = VideoSignURLAccessRights

@typing.final
class VideoFeatures(google.protobuf.message.Message):
    """Contains additional processing features and their results for the video."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _FeatureResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FeatureResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VideoFeatures._FeatureResult.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FEATURE_RESULT_UNSPECIFIED: VideoFeatures._FeatureResult.ValueType  # 0
        """The feature result status is not specified."""
        NOT_REQUESTED: VideoFeatures._FeatureResult.ValueType  # 1
        """The feature processing has not been requested."""
        PROCESSING: VideoFeatures._FeatureResult.ValueType  # 2
        """The feature is currently being processed."""
        SUCCESS: VideoFeatures._FeatureResult.ValueType  # 3
        """The feature processing has completed successfully."""
        FAILED: VideoFeatures._FeatureResult.ValueType  # 4
        """The feature processing has failed."""

    class FeatureResult(_FeatureResult, metaclass=_FeatureResultEnumTypeWrapper):
        """Status of a feature processing request."""

    FEATURE_RESULT_UNSPECIFIED: VideoFeatures.FeatureResult.ValueType  # 0
    """The feature result status is not specified."""
    NOT_REQUESTED: VideoFeatures.FeatureResult.ValueType  # 1
    """The feature processing has not been requested."""
    PROCESSING: VideoFeatures.FeatureResult.ValueType  # 2
    """The feature is currently being processed."""
    SUCCESS: VideoFeatures.FeatureResult.ValueType  # 3
    """The feature processing has completed successfully."""
    FAILED: VideoFeatures.FeatureResult.ValueType  # 4
    """The feature processing has failed."""

    @typing.final
    class Summary(google.protobuf.message.Message):
        """Contains the results of video summarization."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class SummaryURL(google.protobuf.message.Message):
            """Contains a URL to a summarization result for a specific audio track."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            URL_FIELD_NUMBER: builtins.int
            TRACK_INDEX_FIELD_NUMBER: builtins.int
            SRC_LANG_FIELD_NUMBER: builtins.int
            url: builtins.str
            """URL to the summarization result file."""
            track_index: builtins.int
            """Input audio track index (one-based) that was summarized."""
            src_lang: builtins.str
            """Source track language represented as a three-letter code according to ISO 639-2/T."""
            def __init__(
                self,
                *,
                url: builtins.str = ...,
                track_index: builtins.int = ...,
                src_lang: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["src_lang", b"src_lang", "track_index", b"track_index", "url", b"url"]) -> None: ...

        RESULT_FIELD_NUMBER: builtins.int
        URLS_FIELD_NUMBER: builtins.int
        result: global___VideoFeatures.FeatureResult.ValueType
        """Current status of the summarization process."""
        @property
        def urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoFeatures.Summary.SummaryURL]:
            """List of URLs to summarization results for different audio tracks."""

        def __init__(
            self,
            *,
            result: global___VideoFeatures.FeatureResult.ValueType = ...,
            urls: collections.abc.Iterable[global___VideoFeatures.Summary.SummaryURL] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["result", b"result", "urls", b"urls"]) -> None: ...

    SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def summary(self) -> global___VideoFeatures.Summary:
        """Results of the video content summarization process."""

    def __init__(
        self,
        *,
        summary: global___VideoFeatures.Summary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["summary", b"summary"]) -> None: ...

global___VideoFeatures = VideoFeatures



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.clouddesktop.v1.desktop_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UpdatePropertiesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """To get the desktop ID use a [DesktopService.List] request."""
    name: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdatePropertiesRequest = UpdatePropertiesRequest

@typing.final
class StartRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StartRequest = StartRequest

@typing.final
class StopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StopRequest = StopRequest

@typing.final
class UpdateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___UpdateRequest = UpdateRequest

@typing.final
class GetDesktopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop resource to return.

    To get the desktop ID use a [DesktopService.List] request.
    """
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___GetDesktopRequest = GetDesktopRequest

@typing.final
class GetRdpFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop resource to return.

    To get the desktop ID use a [DesktopService.List] request.
    """
    @property
    def user(self) -> yandex.cloud.clouddesktop.v1.desktop_pb2.User:
        """User of the desktop."""

    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        user: yandex.cloud.clouddesktop.v1.desktop_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "user", b"user"]) -> None: ...

global___GetRdpFileRequest = GetRdpFileRequest

@typing.final
class RdpFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """RDP file content."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """HTTP headers mapping."""

    def __init__(
        self,
        *,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "headers", b"headers"]) -> None: ...

global___RdpFileResponse = RdpFileResponse

@typing.final
class ListDesktopsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a DesktopGroup in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDesktopsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDesktopsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Desktop.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. Value or a list of values to compare against the values of the field.
    """
    order_by: builtins.str
    """Sorting the list by [Desktop.name], [Desktop.created_at] and [Desktop.status] fields.
    The default sorting order is ascending.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDesktopsRequest = ListDesktopsRequest

@typing.final
class ListDesktopsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDesktopsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListDesktopsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def desktops(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop]:
        """List of desktops."""

    def __init__(
        self,
        *,
        desktops: collections.abc.Iterable[yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktops", b"desktops", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDesktopsResponse = ListDesktopsResponse

@typing.final
class ListDesktopOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDesktopOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDesktopOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Desktop.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. Value or a list of values to compare against the values of the field.
    """
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDesktopOperationsRequest = ListDesktopOperationsRequest

@typing.final
class ListDesktopOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDesktopOperationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListDesktopOperationsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified desktop."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDesktopOperationsResponse = ListDesktopOperationsResponse

@typing.final
class CreateDesktopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_GROUP_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    desktop_group_id: builtins.str
    """ID of the desktop group."""
    subnet_id: builtins.str
    """ID of the subnet for desktop."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.clouddesktop.v1.desktop_pb2.User]:
        """List of users."""

    def __init__(
        self,
        *,
        desktop_group_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        users: collections.abc.Iterable[yandex.cloud.clouddesktop.v1.desktop_pb2.User] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_group_id", b"desktop_group_id", "subnet_id", b"subnet_id", "users", b"users"]) -> None: ...

global___CreateDesktopRequest = CreateDesktopRequest

@typing.final
class CreateDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop that is being created."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___CreateDesktopMetadata = CreateDesktopMetadata

@typing.final
class DeleteDesktopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop to delete."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___DeleteDesktopRequest = DeleteDesktopRequest

@typing.final
class DeleteDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop that is being deleted."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___DeleteDesktopMetadata = DeleteDesktopMetadata

@typing.final
class ResetPasswordRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    @property
    def user(self) -> yandex.cloud.clouddesktop.v1.desktop_pb2.User:
        """User of the desktop."""

    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        user: yandex.cloud.clouddesktop.v1.desktop_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "user", b"user"]) -> None: ...

global___ResetPasswordRequest = ResetPasswordRequest

@typing.final
class ResetPasswordResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_FIELD_NUMBER: builtins.int
    password: builtins.str
    """Generated password"""
    def __init__(
        self,
        *,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["password", b"password"]) -> None: ...

global___ResetPasswordResponse = ResetPasswordResponse

@typing.final
class RestartRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___RestartRequest = RestartRequest

@typing.final
class RestartDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___RestartDesktopMetadata = RestartDesktopMetadata

@typing.final
class UpdateDesktopPropertiesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___UpdateDesktopPropertiesMetadata = UpdateDesktopPropertiesMetadata

@typing.final
class StartDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StartDesktopMetadata = StartDesktopMetadata

@typing.final
class StopDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StopDesktopMetadata = StopDesktopMetadata

@typing.final
class UpdateDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___UpdateDesktopMetadata = UpdateDesktopMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Connector(google.protobuf.message.Message):
    """Connector configuration. Exactly one connector type must be specified."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HIVE_FIELD_NUMBER: builtins.int
    ICEBERG_FIELD_NUMBER: builtins.int
    DELTA_LAKE_FIELD_NUMBER: builtins.int
    POSTGRESQL_FIELD_NUMBER: builtins.int
    CLICKHOUSE_FIELD_NUMBER: builtins.int
    TPCH_FIELD_NUMBER: builtins.int
    TPCDS_FIELD_NUMBER: builtins.int
    ORACLE_FIELD_NUMBER: builtins.int
    SQLSERVER_FIELD_NUMBER: builtins.int
    @property
    def hive(self) -> global___HiveConnector:
        """Hive connector configuration."""

    @property
    def iceberg(self) -> global___IcebergConnector:
        """Iceberg connector configuration."""

    @property
    def delta_lake(self) -> global___DeltaLakeConnector:
        """Delta Lake connector configuration."""

    @property
    def postgresql(self) -> global___PostgresqlConnector:
        """PostgreSQL connector configuration."""

    @property
    def clickhouse(self) -> global___ClickhouseConnector:
        """ClickHouse connector configuration."""

    @property
    def tpch(self) -> global___TPCHConnector:
        """TPC-H connector for synthetic benchmarking."""

    @property
    def tpcds(self) -> global___TPCDSConnector:
        """TPC-DS connector for synthetic benchmarking."""

    @property
    def oracle(self) -> global___OracleConnector:
        """Oracle connector configuration for connecting to Oracle Database instances."""

    @property
    def sqlserver(self) -> global___SQLServerConnector:
        """SQLServer connector configuration for connecting to SQLServer Database instances."""

    def __init__(
        self,
        *,
        hive: global___HiveConnector | None = ...,
        iceberg: global___IcebergConnector | None = ...,
        delta_lake: global___DeltaLakeConnector | None = ...,
        postgresql: global___PostgresqlConnector | None = ...,
        clickhouse: global___ClickhouseConnector | None = ...,
        tpch: global___TPCHConnector | None = ...,
        tpcds: global___TPCDSConnector | None = ...,
        oracle: global___OracleConnector | None = ...,
        sqlserver: global___SQLServerConnector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "delta_lake", b"delta_lake", "hive", b"hive", "iceberg", b"iceberg", "oracle", b"oracle", "postgresql", b"postgresql", "sqlserver", b"sqlserver", "tpcds", b"tpcds", "tpch", b"tpch", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "delta_lake", b"delta_lake", "hive", b"hive", "iceberg", b"iceberg", "oracle", b"oracle", "postgresql", b"postgresql", "sqlserver", b"sqlserver", "tpcds", b"tpcds", "tpch", b"tpch", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["hive", "iceberg", "delta_lake", "postgresql", "clickhouse", "tpch", "tpcds", "oracle", "sqlserver"] | None: ...

global___Connector = Connector

@typing.final
class Catalog(google.protobuf.message.Message):
    """Catalog is a logical Trino catalog backed by a specific connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONNECTOR_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the catalog."""
    name: builtins.str
    """Name of the catalog."""
    description: builtins.str
    """Description of the catalog."""
    @property
    def connector(self) -> global___Connector:
        """Connector backing this catalog."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels associated with the catalog."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        connector: global___Connector | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connector", b"connector", "description", b"description", "id", b"id", "labels", b"labels", "name", b"name"]) -> None: ...

global___Catalog = Catalog

@typing.final
class CatalogSpec(google.protobuf.message.Message):
    """CatalogSpec defines the desired state of a new catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CONNECTOR_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the catalog.
    Must be unique within a Trino cluster.
    """
    description: builtins.str
    """Description of the catalog."""
    @property
    def connector(self) -> global___Connector:
        """Connector backing this catalog."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels associated with the catalog."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        connector: global___Connector | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connector", b"connector", "description", b"description", "labels", b"labels", "name", b"name"]) -> None: ...

global___CatalogSpec = CatalogSpec

@typing.final
class CatalogUpdateSpec(google.protobuf.message.Message):
    """CatalogUpdateSpec defines changes to an existing catalog.
    Fields are optional and only provided fields will be updated.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CONNECTOR_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """New name of the catalog."""
    description: builtins.str
    """Description of the catalog."""
    @property
    def connector(self) -> global___Connector:
        """Updated connector configuration.
        If specified, replaces the existing connector.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels associated with the catalog."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        connector: global___Connector | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connector", b"connector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connector", b"connector", "description", b"description", "labels", b"labels", "name", b"name"]) -> None: ...

global___CatalogUpdateSpec = CatalogUpdateSpec

@typing.final
class Metastore(google.protobuf.message.Message):
    """Metastore configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HiveMetastore(google.protobuf.message.Message):
        """Configuration of Hive's metastore type."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URI_FIELD_NUMBER: builtins.int
        uri: builtins.str
        """URI or cluster ID of the Hive Metastore."""
        def __init__(
            self,
            *,
            uri: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["connection", b"connection", "uri", b"uri"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["connection", b"connection", "uri", b"uri"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["uri"] | None: ...

    HIVE_FIELD_NUMBER: builtins.int
    @property
    def hive(self) -> global___Metastore.HiveMetastore: ...
    def __init__(
        self,
        *,
        hive: global___Metastore.HiveMetastore | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hive", b"hive", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hive", b"hive", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["hive"] | None: ...

global___Metastore = Metastore

@typing.final
class FileSystem(google.protobuf.message.Message):
    """Configuration of file system used by a connector."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class S3FileSystem(google.protobuf.message.Message):
        """Describes YandexCloud native S3 file system.
        Currently does not require configuration.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class ExternalS3FileSystem(google.protobuf.message.Message):
        """Describes External S3 compatible file system."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AWS_ACCESS_KEY_FIELD_NUMBER: builtins.int
        AWS_SECRET_KEY_FIELD_NUMBER: builtins.int
        AWS_ENDPOINT_FIELD_NUMBER: builtins.int
        AWS_REGION_FIELD_NUMBER: builtins.int
        aws_access_key: builtins.str
        aws_secret_key: builtins.str
        aws_endpoint: builtins.str
        aws_region: builtins.str
        def __init__(
            self,
            *,
            aws_access_key: builtins.str = ...,
            aws_secret_key: builtins.str = ...,
            aws_endpoint: builtins.str = ...,
            aws_region: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["aws_access_key", b"aws_access_key", "aws_endpoint", b"aws_endpoint", "aws_region", b"aws_region", "aws_secret_key", b"aws_secret_key"]) -> None: ...

    S3_FIELD_NUMBER: builtins.int
    EXTERNAL_S3_FIELD_NUMBER: builtins.int
    @property
    def s3(self) -> global___FileSystem.S3FileSystem: ...
    @property
    def external_s3(self) -> global___FileSystem.ExternalS3FileSystem: ...
    def __init__(
        self,
        *,
        s3: global___FileSystem.S3FileSystem | None = ...,
        external_s3: global___FileSystem.ExternalS3FileSystem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["external_s3", b"external_s3", "s3", b"s3", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["external_s3", b"external_s3", "s3", b"s3", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["s3", "external_s3"] | None: ...

global___FileSystem = FileSystem

@typing.final
class HiveConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    METASTORE_FIELD_NUMBER: builtins.int
    FILESYSTEM_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def metastore(self) -> global___Metastore:
        """Metastore configuration."""

    @property
    def filesystem(self) -> global___FileSystem:
        """File system configuration."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        metastore: global___Metastore | None = ...,
        filesystem: global___FileSystem | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filesystem", b"filesystem", "metastore", b"metastore"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "filesystem", b"filesystem", "metastore", b"metastore"]) -> None: ...

global___HiveConnector = HiveConnector

@typing.final
class IcebergConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    METASTORE_FIELD_NUMBER: builtins.int
    FILESYSTEM_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def metastore(self) -> global___Metastore:
        """Metastore configuration."""

    @property
    def filesystem(self) -> global___FileSystem:
        """File system configuration."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        metastore: global___Metastore | None = ...,
        filesystem: global___FileSystem | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filesystem", b"filesystem", "metastore", b"metastore"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "filesystem", b"filesystem", "metastore", b"metastore"]) -> None: ...

global___IcebergConnector = IcebergConnector

@typing.final
class DeltaLakeConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    METASTORE_FIELD_NUMBER: builtins.int
    FILESYSTEM_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def metastore(self) -> global___Metastore:
        """Metastore configuration."""

    @property
    def filesystem(self) -> global___FileSystem:
        """File system configuration."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        metastore: global___Metastore | None = ...,
        filesystem: global___FileSystem | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filesystem", b"filesystem", "metastore", b"metastore"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "filesystem", b"filesystem", "metastore", b"metastore"]) -> None: ...

global___DeltaLakeConnector = DeltaLakeConnector

@typing.final
class PostgresqlConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class OnPremise(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONNECTION_URL_FIELD_NUMBER: builtins.int
        USER_NAME_FIELD_NUMBER: builtins.int
        PASSWORD_FIELD_NUMBER: builtins.int
        connection_url: builtins.str
        """Connection to the Postgresql."""
        user_name: builtins.str
        """Name of the Postgresql user."""
        password: builtins.str
        """Password of the Postgresql user."""
        def __init__(
            self,
            *,
            connection_url: builtins.str = ...,
            user_name: builtins.str = ...,
            password: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["connection_url", b"connection_url", "password", b"password", "user_name", b"user_name"]) -> None: ...

    @typing.final
    class ConnectionManager(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class ConnectionPropertiesEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

        CONNECTION_ID_FIELD_NUMBER: builtins.int
        DATABASE_FIELD_NUMBER: builtins.int
        CONNECTION_PROPERTIES_FIELD_NUMBER: builtins.int
        connection_id: builtins.str
        """Connection ID."""
        database: builtins.str
        """Database."""
        @property
        def connection_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """Additional connection properties."""

        def __init__(
            self,
            *,
            connection_id: builtins.str = ...,
            database: builtins.str = ...,
            connection_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "connection_properties", b"connection_properties", "database", b"database"]) -> None: ...

    ON_PREMISE_FIELD_NUMBER: builtins.int
    CONNECTION_MANAGER_FIELD_NUMBER: builtins.int
    @property
    def on_premise(self) -> global___PostgresqlConnection.OnPremise: ...
    @property
    def connection_manager(self) -> global___PostgresqlConnection.ConnectionManager: ...
    def __init__(
        self,
        *,
        on_premise: global___PostgresqlConnection.OnPremise | None = ...,
        connection_manager: global___PostgresqlConnection.ConnectionManager | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_manager", b"connection_manager", "on_premise", b"on_premise", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_manager", b"connection_manager", "on_premise", b"on_premise", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["on_premise", "connection_manager"] | None: ...

global___PostgresqlConnection = PostgresqlConnection

@typing.final
class PostgresqlConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___PostgresqlConnection:
        """Connection configuration."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        connection: global___PostgresqlConnection | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "connection", b"connection"]) -> None: ...

global___PostgresqlConnector = PostgresqlConnector

@typing.final
class ClickhouseConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class OnPremise(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONNECTION_URL_FIELD_NUMBER: builtins.int
        USER_NAME_FIELD_NUMBER: builtins.int
        PASSWORD_FIELD_NUMBER: builtins.int
        connection_url: builtins.str
        """Connection to the Clickhouse."""
        user_name: builtins.str
        """Name of the Clickhouse user."""
        password: builtins.str
        """Password of the Clickhouse user."""
        def __init__(
            self,
            *,
            connection_url: builtins.str = ...,
            user_name: builtins.str = ...,
            password: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["connection_url", b"connection_url", "password", b"password", "user_name", b"user_name"]) -> None: ...

    @typing.final
    class ConnectionManager(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class ConnectionPropertiesEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

        CONNECTION_ID_FIELD_NUMBER: builtins.int
        DATABASE_FIELD_NUMBER: builtins.int
        CONNECTION_PROPERTIES_FIELD_NUMBER: builtins.int
        connection_id: builtins.str
        """Connection ID."""
        database: builtins.str
        """Database."""
        @property
        def connection_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """Additional connection properties."""

        def __init__(
            self,
            *,
            connection_id: builtins.str = ...,
            database: builtins.str = ...,
            connection_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "connection_properties", b"connection_properties", "database", b"database"]) -> None: ...

    ON_PREMISE_FIELD_NUMBER: builtins.int
    CONNECTION_MANAGER_FIELD_NUMBER: builtins.int
    @property
    def on_premise(self) -> global___ClickhouseConnection.OnPremise: ...
    @property
    def connection_manager(self) -> global___ClickhouseConnection.ConnectionManager: ...
    def __init__(
        self,
        *,
        on_premise: global___ClickhouseConnection.OnPremise | None = ...,
        connection_manager: global___ClickhouseConnection.ConnectionManager | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_manager", b"connection_manager", "on_premise", b"on_premise", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_manager", b"connection_manager", "on_premise", b"on_premise", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["on_premise", "connection_manager"] | None: ...

global___ClickhouseConnection = ClickhouseConnection

@typing.final
class ClickhouseConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___ClickhouseConnection:
        """Connection configuration."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        connection: global___ClickhouseConnection | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "connection", b"connection"]) -> None: ...

global___ClickhouseConnector = ClickhouseConnector

@typing.final
class TPCHConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties"]) -> None: ...

global___TPCHConnector = TPCHConnector

@typing.final
class TPCDSConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties"]) -> None: ...

global___TPCDSConnector = TPCDSConnector

@typing.final
class OracleConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class OnPremise(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONNECTION_URL_FIELD_NUMBER: builtins.int
        USER_NAME_FIELD_NUMBER: builtins.int
        PASSWORD_FIELD_NUMBER: builtins.int
        connection_url: builtins.str
        """Connection to the Oracle."""
        user_name: builtins.str
        """Name of the Oracle user."""
        password: builtins.str
        """Password of the Oracle user."""
        def __init__(
            self,
            *,
            connection_url: builtins.str = ...,
            user_name: builtins.str = ...,
            password: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["connection_url", b"connection_url", "password", b"password", "user_name", b"user_name"]) -> None: ...

    ON_PREMISE_FIELD_NUMBER: builtins.int
    @property
    def on_premise(self) -> global___OracleConnection.OnPremise: ...
    def __init__(
        self,
        *,
        on_premise: global___OracleConnection.OnPremise | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["on_premise", b"on_premise", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["on_premise", b"on_premise", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["on_premise"] | None: ...

global___OracleConnection = OracleConnection

@typing.final
class OracleConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___OracleConnection:
        """Connection configuration."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        connection: global___OracleConnection | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "connection", b"connection"]) -> None: ...

global___OracleConnector = OracleConnector

@typing.final
class SQLServerConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class OnPremise(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONNECTION_URL_FIELD_NUMBER: builtins.int
        USER_NAME_FIELD_NUMBER: builtins.int
        PASSWORD_FIELD_NUMBER: builtins.int
        connection_url: builtins.str
        """Connection to the SQLServer."""
        user_name: builtins.str
        """Name of the SQLServer user."""
        password: builtins.str
        """Password of the SQLServer user."""
        def __init__(
            self,
            *,
            connection_url: builtins.str = ...,
            user_name: builtins.str = ...,
            password: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["connection_url", b"connection_url", "password", b"password", "user_name", b"user_name"]) -> None: ...

    ON_PREMISE_FIELD_NUMBER: builtins.int
    @property
    def on_premise(self) -> global___SQLServerConnection.OnPremise: ...
    def __init__(
        self,
        *,
        on_premise: global___SQLServerConnection.OnPremise | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["on_premise", b"on_premise", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["on_premise", b"on_premise", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["on_premise"] | None: ...

global___SQLServerConnection = SQLServerConnection

@typing.final
class SQLServerConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___SQLServerConnection:
        """Connection configuration."""

    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional properties."""

    def __init__(
        self,
        *,
        connection: global___SQLServerConnection | None = ...,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["additional_properties", b"additional_properties", "connection", b"connection"]) -> None: ...

global___SQLServerConnector = SQLServerConnector



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Backup(google.protobuf.message.Message):
    """An object that represents MySQL backup.

    See [the documentation](/docs/managed-mysql/concepts/backup) for details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BackupCreationType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BackupCreationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Backup._BackupCreationType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BACKUP_CREATION_TYPE_UNSPECIFIED: Backup._BackupCreationType.ValueType  # 0
        AUTOMATED: Backup._BackupCreationType.ValueType  # 1
        """Backup created by automated daily schedule"""
        MANUAL: Backup._BackupCreationType.ValueType  # 2
        """Backup created by user request"""

    class BackupCreationType(_BackupCreationType, metaclass=_BackupCreationTypeEnumTypeWrapper): ...
    BACKUP_CREATION_TYPE_UNSPECIFIED: Backup.BackupCreationType.ValueType  # 0
    AUTOMATED: Backup.BackupCreationType.ValueType  # 1
    """Backup created by automated daily schedule"""
    MANUAL: Backup.BackupCreationType.ValueType  # 2
    """Backup created by user request"""

    class _BackupStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BackupStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Backup._BackupStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BACKUP_STATUS_UNSPECIFIED: Backup._BackupStatus.ValueType  # 0
        DONE: Backup._BackupStatus.ValueType  # 1
        """Backup is done"""
        CREATING: Backup._BackupStatus.ValueType  # 2
        """Backup is creating"""

    class BackupStatus(_BackupStatus, metaclass=_BackupStatusEnumTypeWrapper): ...
    BACKUP_STATUS_UNSPECIFIED: Backup.BackupStatus.ValueType  # 0
    DONE: Backup.BackupStatus.ValueType  # 1
    """Backup is done"""
    CREATING: Backup.BackupStatus.ValueType  # 2
    """Backup is creating"""

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    SOURCE_CLUSTER_ID_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    JOURNAL_SIZE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the backup."""
    folder_id: builtins.str
    """ID of the folder that the backup belongs to."""
    source_cluster_id: builtins.str
    """ID of the cluster that the backup was created for."""
    size: builtins.int
    """Size of backup, in bytes"""
    type: global___Backup.BackupCreationType.ValueType
    """How this backup was created (manual/automatic/etc...)"""
    status: global___Backup.BackupStatus.ValueType
    """Status of backup"""
    journal_size: builtins.int
    """Size of the journal associated with backup, in bytes."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp (the time when the backup operation was completed)."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp (the time when the backup operation was started)."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        source_cluster_id: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        size: builtins.int = ...,
        type: global___Backup.BackupCreationType.ValueType = ...,
        status: global___Backup.BackupStatus.ValueType = ...,
        journal_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "folder_id", b"folder_id", "id", b"id", "journal_size", b"journal_size", "size", b"size", "source_cluster_id", b"source_cluster_id", "started_at", b"started_at", "status", b"status", "type", b"type"]) -> None: ...

global___Backup = Backup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompletionOptions(google.protobuf.message.Message):
    """Defines the options for completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    MAX_TOKENS_FIELD_NUMBER: builtins.int
    REASONING_OPTIONS_FIELD_NUMBER: builtins.int
    stream: builtins.bool
    """Enables streaming of partially generated text."""
    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Affects creativity and randomness of responses. Should be a double number between 0 (inclusive) and 1 (inclusive).
        Lower values produce more straightforward responses while higher values lead to increased creativity and randomness.
        Default temperature: 0.3
        """

    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The limit on the number of tokens used for single completion generation.
        Must be greater than zero. This maximum allowed parameter value may depend on the model being used.
        """

    @property
    def reasoning_options(self) -> global___ReasoningOptions:
        """Configures reasoning capabilities for the model, allowing it to perform internal reasoning before responding."""

    def __init__(
        self,
        *,
        stream: builtins.bool = ...,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        reasoning_options: global___ReasoningOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "reasoning_options", b"reasoning_options", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "reasoning_options", b"reasoning_options", "stream", b"stream", "temperature", b"temperature"]) -> None: ...

global___CompletionOptions = CompletionOptions

@typing.final
class ReasoningOptions(google.protobuf.message.Message):
    """Represents reasoning options that enable the model's ability to perform internal reasoning before generating a response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ReasoningMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ReasoningModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ReasoningOptions._ReasoningMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REASONING_MODE_UNSPECIFIED: ReasoningOptions._ReasoningMode.ValueType  # 0
        """Unspecified reasoning mode."""
        DISABLED: ReasoningOptions._ReasoningMode.ValueType  # 1
        """Disables reasoning. The model will generate a response without performing any internal reasoning."""
        ENABLED_HIDDEN: ReasoningOptions._ReasoningMode.ValueType  # 2
        """Enables reasoning in a hidden manner without exposing the reasoning steps to the user."""

    class ReasoningMode(_ReasoningMode, metaclass=_ReasoningModeEnumTypeWrapper):
        """Enum representing the reasoning mode."""

    REASONING_MODE_UNSPECIFIED: ReasoningOptions.ReasoningMode.ValueType  # 0
    """Unspecified reasoning mode."""
    DISABLED: ReasoningOptions.ReasoningMode.ValueType  # 1
    """Disables reasoning. The model will generate a response without performing any internal reasoning."""
    ENABLED_HIDDEN: ReasoningOptions.ReasoningMode.ValueType  # 2
    """Enables reasoning in a hidden manner without exposing the reasoning steps to the user."""

    MODE_FIELD_NUMBER: builtins.int
    mode: global___ReasoningOptions.ReasoningMode.ValueType
    """Specifies the reasoning mode to be used."""
    def __init__(
        self,
        *,
        mode: global___ReasoningOptions.ReasoningMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mode", b"mode"]) -> None: ...

global___ReasoningOptions = ReasoningOptions

@typing.final
class Message(google.protobuf.message.Message):
    """A message object representing a wrapper over the inputs and outputs of the completion model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TOOL_CALL_LIST_FIELD_NUMBER: builtins.int
    TOOL_RESULT_LIST_FIELD_NUMBER: builtins.int
    role: builtins.str
    """The ID of the message sender. Supported roles:
    * `system`: Special role used to define the behavior of the completion model.
    * `assistant`: A role used by the model to generate responses.
    * `user`: A role used by the user to describe requests to the model.
    """
    text: builtins.str
    """Textual content of the message."""
    @property
    def tool_call_list(self) -> global___ToolCallList:
        """List of tool calls made by the model as part of the response generation."""

    @property
    def tool_result_list(self) -> global___ToolResultList:
        """List of tool results returned from external tools that were invoked by the model."""

    def __init__(
        self,
        *,
        role: builtins.str = ...,
        text: builtins.str = ...,
        tool_call_list: global___ToolCallList | None = ...,
        tool_result_list: global___ToolResultList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Content", b"Content", "text", b"text", "tool_call_list", b"tool_call_list", "tool_result_list", b"tool_result_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Content", b"Content", "role", b"role", "text", b"text", "tool_call_list", b"tool_call_list", "tool_result_list", b"tool_result_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Content", b"Content"]) -> typing.Literal["text", "tool_call_list", "tool_result_list"] | None: ...

global___Message = Message

@typing.final
class ContentUsage(google.protobuf.message.Message):
    """An object representing the number of content [tokens](/docs/foundation-models/concepts/yandexgpt/tokens) used by the completion model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CompletionTokensDetails(google.protobuf.message.Message):
        """Provides additional information about how the completion tokens were utilized."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REASONING_TOKENS_FIELD_NUMBER: builtins.int
        reasoning_tokens: builtins.int
        """The number of tokens used specifically for internal reasoning performed by the model."""
        def __init__(
            self,
            *,
            reasoning_tokens: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["reasoning_tokens", b"reasoning_tokens"]) -> None: ...

    INPUT_TEXT_TOKENS_FIELD_NUMBER: builtins.int
    COMPLETION_TOKENS_FIELD_NUMBER: builtins.int
    TOTAL_TOKENS_FIELD_NUMBER: builtins.int
    COMPLETION_TOKENS_DETAILS_FIELD_NUMBER: builtins.int
    input_text_tokens: builtins.int
    """The number of tokens in the textual part of the model input."""
    completion_tokens: builtins.int
    """The number of tokens in the generated completion."""
    total_tokens: builtins.int
    """The total number of tokens, including all input tokens and all generated tokens."""
    @property
    def completion_tokens_details(self) -> global___ContentUsage.CompletionTokensDetails:
        """Provides additional information about how the completion tokens were utilized."""

    def __init__(
        self,
        *,
        input_text_tokens: builtins.int = ...,
        completion_tokens: builtins.int = ...,
        total_tokens: builtins.int = ...,
        completion_tokens_details: global___ContentUsage.CompletionTokensDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completion_tokens_details", b"completion_tokens_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["completion_tokens", b"completion_tokens", "completion_tokens_details", b"completion_tokens_details", "input_text_tokens", b"input_text_tokens", "total_tokens", b"total_tokens"]) -> None: ...

global___ContentUsage = ContentUsage

@typing.final
class Alternative(google.protobuf.message.Message):
    """Represents a generated completion alternative, including its content and generation status."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AlternativeStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AlternativeStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Alternative._AlternativeStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALTERNATIVE_STATUS_UNSPECIFIED: Alternative._AlternativeStatus.ValueType  # 0
        """Unspecified generation status."""
        ALTERNATIVE_STATUS_PARTIAL: Alternative._AlternativeStatus.ValueType  # 1
        """Partially generated alternative."""
        ALTERNATIVE_STATUS_TRUNCATED_FINAL: Alternative._AlternativeStatus.ValueType  # 2
        """Incomplete final alternative resulting from reaching the maximum allowed number of tokens."""
        ALTERNATIVE_STATUS_FINAL: Alternative._AlternativeStatus.ValueType  # 3
        """Final alternative generated without running into any limits."""
        ALTERNATIVE_STATUS_CONTENT_FILTER: Alternative._AlternativeStatus.ValueType  # 4
        """Generation was stopped due to the discovery of potentially sensitive content in the prompt or generated response.
        To fix, modify the prompt and restart generation.
        """
        ALTERNATIVE_STATUS_TOOL_CALLS: Alternative._AlternativeStatus.ValueType  # 5
        """Tools were invoked during the completion generation."""

    class AlternativeStatus(_AlternativeStatus, metaclass=_AlternativeStatusEnumTypeWrapper):
        """Enum representing the generation status of the alternative."""

    ALTERNATIVE_STATUS_UNSPECIFIED: Alternative.AlternativeStatus.ValueType  # 0
    """Unspecified generation status."""
    ALTERNATIVE_STATUS_PARTIAL: Alternative.AlternativeStatus.ValueType  # 1
    """Partially generated alternative."""
    ALTERNATIVE_STATUS_TRUNCATED_FINAL: Alternative.AlternativeStatus.ValueType  # 2
    """Incomplete final alternative resulting from reaching the maximum allowed number of tokens."""
    ALTERNATIVE_STATUS_FINAL: Alternative.AlternativeStatus.ValueType  # 3
    """Final alternative generated without running into any limits."""
    ALTERNATIVE_STATUS_CONTENT_FILTER: Alternative.AlternativeStatus.ValueType  # 4
    """Generation was stopped due to the discovery of potentially sensitive content in the prompt or generated response.
    To fix, modify the prompt and restart generation.
    """
    ALTERNATIVE_STATUS_TOOL_CALLS: Alternative.AlternativeStatus.ValueType  # 5
    """Tools were invoked during the completion generation."""

    MESSAGE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    status: global___Alternative.AlternativeStatus.ValueType
    """The generation status of the alternative."""
    @property
    def message(self) -> global___Message:
        """A message with the content of the alternative."""

    def __init__(
        self,
        *,
        message: global___Message | None = ...,
        status: global___Alternative.AlternativeStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "status", b"status"]) -> None: ...

global___Alternative = Alternative

@typing.final
class Token(google.protobuf.message.Message):
    """Represents a token, the basic unit of content, used by the foundation model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    SPECIAL_FIELD_NUMBER: builtins.int
    id: builtins.int
    """An internal token identifier."""
    text: builtins.str
    """The textual representation of the token."""
    special: builtins.bool
    """Indicates whether the token is special or not. Special tokens may define the model's behavior and are not visible to users."""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        text: builtins.str = ...,
        special: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "special", b"special", "text", b"text"]) -> None: ...

global___Token = Token

@typing.final
class Tool(google.protobuf.message.Message):
    """Represents a tool that can be invoked during completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_FIELD_NUMBER: builtins.int
    @property
    def function(self) -> global___FunctionTool:
        """Represents a function that can be called."""

    def __init__(
        self,
        *,
        function: global___FunctionTool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolType", b"ToolType"]) -> typing.Literal["function"] | None: ...

global___Tool = Tool

@typing.final
class FunctionTool(google.protobuf.message.Message):
    """Represents a function tool that can be invoked during completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    STRICT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function."""
    description: builtins.str
    """A description of the function's purpose or behavior."""
    strict: builtins.bool
    """Enforces strict adherence to the function schema, ensuring only defined parameters are used."""
    @property
    def parameters(self) -> google.protobuf.struct_pb2.Struct:
        """A JSON Schema that defines the expected parameters for the function.
        The schema should describe the required fields, their types, and any constraints or default values.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        parameters: google.protobuf.struct_pb2.Struct | None = ...,
        strict: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parameters", b"parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "parameters", b"parameters", "strict", b"strict"]) -> None: ...

global___FunctionTool = FunctionTool

@typing.final
class ToolCall(google.protobuf.message.Message):
    """Represents a call to a tool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_CALL_FIELD_NUMBER: builtins.int
    @property
    def function_call(self) -> global___FunctionCall:
        """Represents a call to a function."""

    def __init__(
        self,
        *,
        function_call: global___FunctionCall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolCallType", b"ToolCallType"]) -> typing.Literal["function_call"] | None: ...

global___ToolCall = ToolCall

@typing.final
class FunctionCall(google.protobuf.message.Message):
    """Represents the invocation of a function with specific arguments."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function being called."""
    @property
    def arguments(self) -> google.protobuf.struct_pb2.Struct:
        """The structured arguments passed to the function.
        These arguments must adhere to the JSON Schema defined in the corresponding function's parameters.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        arguments: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["arguments", b"arguments"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "name", b"name"]) -> None: ...

global___FunctionCall = FunctionCall

@typing.final
class ToolCallList(google.protobuf.message.Message):
    """Represents a list of tool calls."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_CALLS_FIELD_NUMBER: builtins.int
    @property
    def tool_calls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolCall]:
        """A list of tool calls to be executed."""

    def __init__(
        self,
        *,
        tool_calls: collections.abc.Iterable[global___ToolCall] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_calls", b"tool_calls"]) -> None: ...

global___ToolCallList = ToolCallList

@typing.final
class ToolResult(google.protobuf.message.Message):
    """Represents the result of a tool call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_RESULT_FIELD_NUMBER: builtins.int
    @property
    def function_result(self) -> global___FunctionResult:
        """Represents the result of a function call."""

    def __init__(
        self,
        *,
        function_result: global___FunctionResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolResultType", b"ToolResultType"]) -> typing.Literal["function_result"] | None: ...

global___ToolResult = ToolResult

@typing.final
class FunctionResult(google.protobuf.message.Message):
    """Represents the result of a function call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function that was executed."""
    content: builtins.str
    """The result of the function call, represented as a string.
    This field can be used to store the output of the function.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content", "name", b"name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ContentType", b"ContentType"]) -> typing.Literal["content"] | None: ...

global___FunctionResult = FunctionResult

@typing.final
class ToolResultList(google.protobuf.message.Message):
    """Represents a list of tool results."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def tool_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolResult]:
        """A list of tool results."""

    def __init__(
        self,
        *,
        tool_results: collections.abc.Iterable[global___ToolResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_results", b"tool_results"]) -> None: ...

global___ToolResultList = ToolResultList

@typing.final
class JsonSchema(google.protobuf.message.Message):
    """Represents the expected structure of the model's response using a JSON Schema."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEMA_FIELD_NUMBER: builtins.int
    @property
    def schema(self) -> google.protobuf.struct_pb2.Struct:
        """The JSON Schema that the model's output must conform to."""

    def __init__(
        self,
        *,
        schema: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["schema", b"schema"]) -> None: ...

global___JsonSchema = JsonSchema

@typing.final
class ToolChoice(google.protobuf.message.Message):
    """Specifies how the model should select which tool (or tools) to use when generating a response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ToolChoiceMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ToolChoiceModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ToolChoice._ToolChoiceMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TOOL_CHOICE_MODE_UNSPECIFIED: ToolChoice._ToolChoiceMode.ValueType  # 0
        """The server will choose the default behavior, which is AUTO."""
        NONE: ToolChoice._ToolChoiceMode.ValueType  # 1
        """The model will not call any tool and will generate a standard text response."""
        AUTO: ToolChoice._ToolChoiceMode.ValueType  # 2
        """The model can choose between generating a text response or calling one or more tools.
        This is the default behavior.
        """
        REQUIRED: ToolChoice._ToolChoiceMode.ValueType  # 3
        """The model is required to call one or more tools."""

    class ToolChoiceMode(_ToolChoiceMode, metaclass=_ToolChoiceModeEnumTypeWrapper):
        """Defines the different modes for tool calling."""

    TOOL_CHOICE_MODE_UNSPECIFIED: ToolChoice.ToolChoiceMode.ValueType  # 0
    """The server will choose the default behavior, which is AUTO."""
    NONE: ToolChoice.ToolChoiceMode.ValueType  # 1
    """The model will not call any tool and will generate a standard text response."""
    AUTO: ToolChoice.ToolChoiceMode.ValueType  # 2
    """The model can choose between generating a text response or calling one or more tools.
    This is the default behavior.
    """
    REQUIRED: ToolChoice.ToolChoiceMode.ValueType  # 3
    """The model is required to call one or more tools."""

    MODE_FIELD_NUMBER: builtins.int
    FUNCTION_NAME_FIELD_NUMBER: builtins.int
    mode: global___ToolChoice.ToolChoiceMode.ValueType
    """Specifies the overall tool-calling mode."""
    function_name: builtins.str
    """Forces the model to call a specific function.
    The provided string must match the name of a function in the API request.
    """
    def __init__(
        self,
        *,
        mode: global___ToolChoice.ToolChoiceMode.ValueType = ...,
        function_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolChoice", b"ToolChoice", "function_name", b"function_name", "mode", b"mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolChoice", b"ToolChoice", "function_name", b"function_name", "mode", b"mode"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolChoice", b"ToolChoice"]) -> typing.Literal["mode", "function_name"] | None: ...

global___ToolChoice = ToolChoice



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/ocr/v1/ocr_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/ocr/v1/ocr_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.ocr.v1 import ocr_pb2 as yandex_dot_cloud_dot_ai_dot_ocr_dot_v1_dot_ocr__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ai/ocr/v1/ocr_service.proto\x12\x16yandex.cloud.ai.ocr.v1\x1a yandex/cloud/ai/ocr/v1/ocr.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"w\n\x14RecognizeTextRequest\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12\x11\n\tmime_type\x18\x02 \x01(\t\x12\x16\n\x0elanguage_codes\x18\x03 \x03(\t\x12\x17\n\x05model\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50B\x08\n\x06source\"f\n\x15RecognizeTextResponse\x12?\n\x0ftext_annotation\x18\x01 \x01(\x0b\x32&.yandex.cloud.ai.ocr.v1.TextAnnotation\x12\x0c\n\x04page\x18\x02 \x01(\x03\";\n\x15GetRecognitionRequest\x12\"\n\x0coperation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xa7\x01\n\x16TextRecognitionService\x12\x8c\x01\n\tRecognize\x12,.yandex.cloud.ai.ocr.v1.RecognizeTextRequest\x1a-.yandex.cloud.ai.ocr.v1.RecognizeTextResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/ocr/v1/recognizeText:\x01*0\x01\x32\xd1\x02\n\x1bTextRecognitionAsyncService\x12\x9e\x01\n\tRecognize\x12,.yandex.cloud.ai.ocr.v1.RecognizeTextRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1a/ocr/v1/recognizeTextAsync:\x01*\x12\x90\x01\n\x0eGetRecognition\x12-.yandex.cloud.ai.ocr.v1.GetRecognitionRequest\x1a-.yandex.cloud.ai.ocr.v1.RecognizeTextResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/ocr/v1/getRecognition0\x01\x42\\\n\x1ayandex.cloud.api.ai.ocr.v1Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/ocr/v1;ocrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.ocr.v1.ocr_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.ai.ocr.v1Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/ocr/v1;ocr'
  _globals['_RECOGNIZETEXTREQUEST'].fields_by_name['model']._loaded_options = None
  _globals['_RECOGNIZETEXTREQUEST'].fields_by_name['model']._serialized_options = b'\212\3101\004<=50'
  _globals['_GETRECOGNITIONREQUEST'].fields_by_name['operation_id']._loaded_options = None
  _globals['_GETRECOGNITIONREQUEST'].fields_by_name['operation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TEXTRECOGNITIONSERVICE'].methods_by_name['Recognize']._loaded_options = None
  _globals['_TEXTRECOGNITIONSERVICE'].methods_by_name['Recognize']._serialized_options = b'\202\323\344\223\002\032\"\025/ocr/v1/recognizeText:\001*'
  _globals['_TEXTRECOGNITIONASYNCSERVICE'].methods_by_name['Recognize']._loaded_options = None
  _globals['_TEXTRECOGNITIONASYNCSERVICE'].methods_by_name['Recognize']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002\037\"\032/ocr/v1/recognizeTextAsync:\001*'
  _globals['_TEXTRECOGNITIONASYNCSERVICE'].methods_by_name['GetRecognition']._loaded_options = None
  _globals['_TEXTRECOGNITIONASYNCSERVICE'].methods_by_name['GetRecognition']._serialized_options = b'\202\323\344\223\002\030\022\026/ocr/v1/getRecognition'
  _globals['_RECOGNIZETEXTREQUEST']._serialized_start=237
  _globals['_RECOGNIZETEXTREQUEST']._serialized_end=356
  _globals['_RECOGNIZETEXTRESPONSE']._serialized_start=358
  _globals['_RECOGNIZETEXTRESPONSE']._serialized_end=460
  _globals['_GETRECOGNITIONREQUEST']._serialized_start=462
  _globals['_GETRECOGNITIONREQUEST']._serialized_end=521
  _globals['_TEXTRECOGNITIONSERVICE']._serialized_start=524
  _globals['_TEXTRECOGNITIONSERVICE']._serialized_end=691
  _globals['_TEXTRECOGNITIONASYNCSERVICE']._serialized_start=694
  _globals['_TEXTRECOGNITIONASYNCSERVICE']._serialized_end=1031
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Origin(google.protobuf.message.Message):
    """An origin. For details about the concept, see [documentation](/docs/cdn/concepts/origins)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    BACKUP_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """ID of the origin."""
    origin_group_id: builtins.int
    """ID of the parent origin group."""
    source: builtins.str
    """IP address or Domain name of your origin and the port (if custom).
    Used if [meta] variant is `common`.
    """
    enabled: builtins.bool
    """The setting allows to enable or disable an Origin source in the Origins group.

    It has two possible values:

    True - The origin is enabled and used as a source for the CDN. An origins
    group must contain at least one enabled origin.
    False - The origin is disabled and the CDN is not using it to pull content.
    """
    backup: builtins.bool
    """Specifies whether the origin is used in its origin group as backup.
    A backup origin is used when one of active origins becomes unavailable.
    """
    provider_type: builtins.str
    """Type of the CDN provider for this origin group."""
    @property
    def meta(self) -> global___OriginMeta:
        """Set up origin of the content."""

    def __init__(
        self,
        *,
        id: builtins.int = ...,
        origin_group_id: builtins.int = ...,
        source: builtins.str = ...,
        enabled: builtins.bool = ...,
        backup: builtins.bool = ...,
        meta: global___OriginMeta | None = ...,
        provider_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup", b"backup", "enabled", b"enabled", "id", b"id", "meta", b"meta", "origin_group_id", b"origin_group_id", "provider_type", b"provider_type", "source", b"source"]) -> None: ...

global___Origin = Origin

@typing.final
class OriginParams(google.protobuf.message.Message):
    """Origin parameters. For details about the concept, see [documentation](/docs/cdn/concepts/origins)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    BACKUP_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    source: builtins.str
    """Source: IP address or Domain name of your origin and the port (if custom)."""
    enabled: builtins.bool
    """The setting allows to enable or disable an Origin source in the Origins group.

    It has two possible values:

    True - The origin is enabled and used as a source for the CDN. An origins
    group must contain at least one enabled origins. False - The origin is disabled
    and the CDN is not using it to pull content.
    """
    backup: builtins.bool
    """backup option has two possible values:

      True - The option is active. The origin will not be used until one of
             active origins become unavailable.
      False - The option is disabled.
    """
    @property
    def meta(self) -> global___OriginMeta:
        """Set up origin of the content."""

    def __init__(
        self,
        *,
        source: builtins.str = ...,
        enabled: builtins.bool = ...,
        backup: builtins.bool = ...,
        meta: global___OriginMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup", b"backup", "enabled", b"enabled", "meta", b"meta", "source", b"source"]) -> None: ...

global___OriginParams = OriginParams

@typing.final
class OriginMeta(google.protobuf.message.Message):
    """Origin type. For details about the concept, see [documentation](/docs/cdn/concepts/origins)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMON_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    WEBSITE_FIELD_NUMBER: builtins.int
    BALANCER_FIELD_NUMBER: builtins.int
    @property
    def common(self) -> global___OriginNamedMeta:
        """A server with a domain name linked to it"""

    @property
    def bucket(self) -> global___OriginNamedMeta:
        """An Object Storage bucket not configured as a static site hosting."""

    @property
    def website(self) -> global___OriginNamedMeta:
        """An Object Storage bucket configured as a static site hosting."""

    @property
    def balancer(self) -> global___OriginBalancerMeta:
        """An L7 load balancer from Application Load Balancer.
        CDN servers will access the load balancer at one of its IP addresses that must be selected in the origin settings.
        """

    def __init__(
        self,
        *,
        common: global___OriginNamedMeta | None = ...,
        bucket: global___OriginNamedMeta | None = ...,
        website: global___OriginNamedMeta | None = ...,
        balancer: global___OriginBalancerMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["balancer", b"balancer", "bucket", b"bucket", "common", b"common", "origin_meta_variant", b"origin_meta_variant", "website", b"website"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["balancer", b"balancer", "bucket", b"bucket", "common", b"common", "origin_meta_variant", b"origin_meta_variant", "website", b"website"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["origin_meta_variant", b"origin_meta_variant"]) -> typing.Literal["common", "bucket", "website", "balancer"] | None: ...

global___OriginMeta = OriginMeta

@typing.final
class OriginNamedMeta(google.protobuf.message.Message):
    """Origin info. For details about the concept, see [documentation](/docs/cdn/concepts/origins)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the origin."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___OriginNamedMeta = OriginNamedMeta

@typing.final
class OriginBalancerMeta(google.protobuf.message.Message):
    """Application Load Balancer origin info. For details about the concept, see [documentation](/docs/cdn/concepts/origins)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the origin."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___OriginBalancerMeta = OriginBalancerMeta



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/licensemanager/v1/external_instance.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/licensemanager/v1/external_instance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/marketplace/licensemanager/v1/external_instance.proto\x12*yandex.cloud.marketplace.licensemanager.v1\"\xef\x02\n\x10\x45xternalInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12`\n\nproperties\x18\x15 \x03(\x0b\x32L.yandex.cloud.marketplace.licensemanager.v1.ExternalInstance.PropertiesEntry\x12X\n\x0csubscription\x18\x16 \x01(\x0b\x32@.yandex.cloud.marketplace.licensemanager.v1.ExternalSubscriptionH\x00\x12N\n\x07license\x18\x17 \x01(\x0b\x32;.yandex.cloud.marketplace.licensemanager.v1.ExternalLicenseH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06vendorJ\x04\x08\x02\x10\x15\"[\n\x14\x45xternalSubscription\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\x12\x12\n\nlicense_id\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x63tivation_key\x18\x03 \x01(\t\"6\n\x0f\x45xternalLicense\x12\x12\n\nlicense_id\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x42\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.v1.external_instance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager'
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._loaded_options = None
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_EXTERNALINSTANCE']._serialized_start=115
  _globals['_EXTERNALINSTANCE']._serialized_end=482
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._serialized_start=417
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._serialized_end=466
  _globals['_EXTERNALSUBSCRIPTION']._serialized_start=484
  _globals['_EXTERNALSUBSCRIPTION']._serialized_end=575
  _globals['_EXTERNALLICENSE']._serialized_start=577
  _globals['_EXTERNALLICENSE']._serialized_end=631
# @@protoc_insertion_point(module_scope)
